import { addComponent, defineNuxtModule, createResolver, addImports } from '@nuxt/kit';
import { Components } from 'bootstrap-vue-next';

const useComponents = () => {
  Object.keys(Components).forEach((name) => {
    addComponent({
      name,
      export: name,
      filePath: "bootstrap-vue-next"
    });
  });
};

const parseActiveImports = (options, values) => {
  const { all, ...others } = options;
  const valuesCopy = {};
  if (all) {
    values.forEach((el) => {
      valuesCopy[el] = all;
    });
  }
  const merge = { ...valuesCopy, ...others };
  return Object.entries(merge).filter(([name, value]) => !!value && values.includes(name)).map(([name]) => name);
};

const module = defineNuxtModule({
  meta: {
    name: "bootstrap-vue-next",
    configKey: "bootstrapVueNext",
    compatibility: {
      nuxt: "^3.0.0",
      bridge: false
    }
  },
  defaults: {
    composables: true
  },
  setup(options, nuxt) {
    const resolver = createResolver(import.meta.url);
    const normalizedComposables = typeof options.composables === "boolean" ? { all: options.composables } : options.composables;
    nuxt.options.build.transpile.push(resolver.resolve("./runtime"));
    nuxt.options.css.push("bootstrap-vue-next/dist/bootstrap-vue-next.css");
    useComponents();
    const arr = [];
    if (Object.values(normalizedComposables).some((el) => el === true)) {
      const imports = parseActiveImports(normalizedComposables, [
        "useBreadcrumb",
        "useColorMode"
      ]).map(
        (el) => ({
          from: resolver.resolve("./runtime/composables"),
          name: el
        })
      );
      arr.push(...imports);
    }
    if (arr.length) {
      addImports(arr);
    }
  }
});

export { module as default };
